# Py4Uview: Tools for Uview images

## Introduction
__Py4Uview__ provides a set of tools for images saved by Uivew, which is used by SPEELEEM in MAXPEEM to save the user's data in format of .dat file. Py4Uview can read the image and metadata from the file saved by Uview software.

## Quick start
### Install
```
python -m pip install py4uview
```
### import
``` python
>>> import py4uview
```